@@ -1313,13 +1313,13 @@ user_authenticate(char *buf, char *passwd_file, char *salt, int salt_len)
 
 	/* strcpy() should be OK, but use strncpy() to be extra careful */
 	strncpy(packet_username, buf, MAX_USER_PASSWD_LEN);
-	index = (char *) memchr(buf, '\0', MAX_USER_PASSWD_LEN) + 1;
+	index = (char *) memchr(buf, '\0', MAX_USER_PASSWD_LEN);
 	if (index == NULL)
 	{
 		pool_debug("pcp_child: error while reading authentication packet");
 		return 0;
 	}
-	strncpy(packet_password, index, MAX_USER_PASSWD_LEN);
+	strncpy(packet_password, ++index, MAX_USER_PASSWD_LEN);
 
 	fp = fopen(passwd_file, "r");
 	if (fp == NULL)
