@@ -3,7 +3,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2013	PgPool Global Development Group
+ * Copyright (c) 2003-2014	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -1927,7 +1927,7 @@ static void pool_update_fsmm(POOL_CACHE_BLOCKID blockid, size_t free_space)
 		return;
 	}
 
-	if (free_space < 0 || free_space > POOL_MAX_FREE_SPACE)
+	if (free_space > POOL_MAX_FREE_SPACE)
 	{
 		pool_error("pool_set_free_space: invalid free space %zd", free_space);
 		return;
@@ -2325,7 +2325,7 @@ static int pool_delete_item_shmem_cache(POOL_CACHEID *cacheid)
 		return -1;
 	}
 
-	if (cacheid->itemid < 0 || cacheid->itemid >= bh->num_items)
+	if (cacheid->itemid >= bh->num_items)
 	{
 		/*
 		 * This could happen if the block is reused.  Since contents
@@ -2410,7 +2410,7 @@ static POOL_CACHE_ITEM_HEADER *pool_cache_item_header(POOL_CACHEID *cacheid)
 	}
 
 	bh = (POOL_CACHE_BLOCK_HEADER *)block_address(cacheid->blockid);
-	if (cacheid->itemid < 0 || cacheid->itemid >= bh->num_items)
+	if (cacheid->itemid >= bh->num_items)
 	{
 		pool_error("pool_cache_item_header: invalid item id %d", cacheid->itemid);
 		return NULL;
@@ -3129,8 +3129,10 @@ void pool_handle_query_cache(POOL_CONNECTION_POOL *backend, char *query, Node *n
 			{
 				pool_error("ReadyForQuery: pool_commit_cache failed");
 			}
-			free(oids);
-			free(cache_buffer);
+			if (oids)
+				free(oids);
+			if (cache_buffer)
+				free(cache_buffer);
 		}
 		pool_shmem_unlock();
 		POOL_SETMASK(&oldmask);
@@ -3143,7 +3145,7 @@ void pool_handle_query_cache(POOL_CONNECTION_POOL *backend, char *query, Node *n
 	else		/* Non cache safe queries */
 	{
 		/* Non cachable SELECT */
-		if (IsA(node, SelectStmt))
+		if (node && IsA(node, SelectStmt))
 		{
 			if (state == 'I')
 			{
