@@ -6,7 +6,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2013	PgPool Global Development Group
+ * Copyright (c) 2003-2014	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -100,6 +100,7 @@ void pool_start_query(POOL_QUERY_CONTEXT *query_context, char *query, int len, N
 		query_context->parse_tree = node;
 		query_context->virtual_master_node_id = my_master_node_id;
 		query_context->is_cache_safe = false;
+		query_context->num_original_params = -1;
 		if (pool_config->memory_cache_enabled)
 			query_context->temp_cache = pool_create_temp_query_cache(query);
 		pool_set_query_in_progress();
@@ -171,6 +172,14 @@ void pool_clear_node_to_be_sent(POOL_QUERY_CONTEXT *query_context)
 void pool_setall_node_to_be_sent(POOL_QUERY_CONTEXT *query_context)
 {
 	int i;
+	POOL_SESSION_CONTEXT *sc;
+
+	sc = pool_get_session_context();
+	if (!sc)
+	{
+		pool_error("pool_setall_node_to_be_sent: no session context");
+		return;
+	}
 
 	if (!query_context)
 	{
@@ -182,7 +191,20 @@ void pool_setall_node_to_be_sent(POOL_QUERY_CONTEXT *query_context)
 	{
 		if (private_backend_status[i] == CON_UP ||
 			(private_backend_status[i] == CON_CONNECT_WAIT))
+		{
+			/*
+			 * In streaming replication mode, if the node is not
+			 * primary node nor load balance node, there's no point to
+			 * send query.
+			 */
+			if (pool_config->master_slave_mode &&
+				!strcmp(pool_config->master_slave_sub_mode, MODE_STREAMREP) &&
+				i != PRIMARY_NODE_ID && i != sc->load_balance_node_id)
+			{
+				continue;
+			}
 			query_context->where_to_send[i] = true;
+		}
 	}
 	return;
 }
