@@ -79,6 +79,7 @@ POOL_CONNECTION *pool_open(int fd)
 	if (cp->hp == NULL)
 	{
 		pool_error("pool_open: malloc failed");
+		free(cp);
 		return NULL;
 	}
 	cp->bufsz = READBUFSZ;
@@ -137,7 +138,7 @@ int pool_read(POOL_CONNECTION *cp, void *buf, int len)
 	{
 		if (pool_check_fd(cp))
 		{
-			if (!IS_MASTER_NODE_ID(cp->db_node_id))
+			if (!IS_MASTER_NODE_ID(cp->db_node_id) && (getpid() != mypid))
 			{
 				pool_log("pool_read: data is not ready in DB node: %d. abort this session",
 						 cp->db_node_id);
@@ -168,11 +169,13 @@ int pool_read(POOL_CONNECTION *cp, void *buf, int len)
 
 			if (cp->isbackend)
 			{
-				/* if fail_over_on_backend_erro is true, then trigger failover */
+				/* if fail_over_on_backend_error is true, then trigger failover */
 				if (pool_config->fail_over_on_backend_error)
 				{
 					notice_backend_error(cp->db_node_id);
 					child_exit(1);
+					pool_log("pool_read: do not failover because I am the main process");
+					return -1;
 				}
 				else
 				{
@@ -291,11 +294,13 @@ char *pool_read2(POOL_CONNECTION *cp, int len)
 
 			if (cp->isbackend)
 			{
-				/* if fail_over_on_backend_erro is true, then trigger failover */
+				/* if fail_over_on_backend_error is true, then trigger failover */
 				if (pool_config->fail_over_on_backend_error)
 				{
 					notice_backend_error(cp->db_node_id);
 					child_exit(1);
+					pool_log("pool_read2: do not failover because I am the main process");
+					return NULL;
 				}
 				else
 				{
@@ -430,7 +435,7 @@ int pool_flush_it(POOL_CONNECTION *cp)
 			}
 			else if (FD_ISSET(cp->fd, &exceptmask))
 			{
-				pool_log("pool_flush_it: exception occured");
+				pool_log("pool_flush_it: exception occurred");
 				cp->wbufpo = 0;
 				return -1;
 			}
@@ -503,11 +508,13 @@ int pool_flush(POOL_CONNECTION *cp)
 	{
 		if (cp->isbackend)
 		{
-			/* if fail_over_on_backend_erro is true, then trigger failover */
+			/* if fail_over_on_backend_error is true, then trigger failover */
 			if (pool_config->fail_over_on_backend_error)
 			{
 				notice_backend_error(cp->db_node_id);
 				child_exit(1);
+				pool_log("pool_flush: do not failover because I am the main process");
+				return -1;
 			}
 			else
 			{
@@ -650,6 +657,7 @@ char *pool_read_string(POOL_CONNECTION *cp, int *len, int line)
 			{
 				notice_backend_error(cp->db_node_id);
 				child_exit(1);
+				return NULL;
 			}
 			else
 			{
